==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/vo/SubpackagematerialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.bean.RecordmaterialanalysisEntity;
import com.ejianc.business.record.vo.RecordsubpackagematerialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class SubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Double total;//合计数量汇总
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String sort;
    private java.lang.String billStateStr;


    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }

    private List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析子表
    private List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS = new ArrayList<>(); // 分包施工图预算材料分析子表


    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
     /**
      * 分包施工图预算材料分析子表
      */
    public List<SubpackagematerialanalysisdetailVO> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }
    /**
      * 分包施工图预算材料分析子表
      */
    public void setSubpackagematerialanalysisdetailEntities(List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    /**
      * 分包施工图预算材料分析变更记录子表
      */
    public List<RecordsubpackagematerialanalysisVO> getRecordsubpackagematerialanalysisVOS() {
        return recordsubpackagematerialanalysisVOS;
    }

    public void setRecordsubpackagematerialanalysisVOS(List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS) {
        this.recordsubpackagematerialanalysisVOS = recordsubpackagematerialanalysisVOS;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/bedget/vo/SubpackagematerialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import com.ejianc.business.record.vo.RecordsubpackagematerialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 分包施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class SubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Double total;//合计数量汇总
    private java.lang.String createTimeShow; // 创建时间文本显示
    private java.lang.String sort;
    private java.lang.String billStateStr;
    private java.lang.Long orgId; // 所属组织id
    private java.lang.String orgName; // 所属组织名称
    private java.lang.Long projectDepartmentId; // 项目部id


    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }

    private List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析子表
    private List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS = new ArrayList<>(); // 分包施工图预算材料分析子表


    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
     /**
      * 分包施工图预算材料分析子表
      */
    public List<SubpackagematerialanalysisdetailVO> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }
    /**
      * 分包施工图预算材料分析子表
      */
    public void setSubpackagematerialanalysisdetailEntities(List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    /**
      * 分包施工图预算材料分析变更记录子表
      */
    public List<RecordsubpackagematerialanalysisVO> getRecordsubpackagematerialanalysisVOS() {
        return recordsubpackagematerialanalysisVOS;
    }

    public void setRecordsubpackagematerialanalysisVOS(List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS) {
        this.recordsubpackagematerialanalysisVOS = recordsubpackagematerialanalysisVOS;
    }

    public String getCreateTimeShow() {
        return createTimeShow;
    }

    public void setCreateTimeShow(String createTimeShow) {
        this.createTimeShow = createTimeShow;
    }

    public String getSort() {
        return sort;
    }

    public void setSort(String sort) {
        this.sort = sort;
    }

    public String getBillStateStr() {
        return billStateStr;
    }

    public void setBillStateStr(String billStateStr) {
        this.billStateStr = billStateStr;
    }
}
